<?php
if ($type == "jpg") { $type = "jpeg"; }
header("Content-Type: image/" . $type);
header("Cache-Control: max-age=0");
header("Expires: ".gmdate("D, d M Y H:i:s", time())." GMT");
include ("../application.inc.php");
readfile ("$CFG->productsdir" . "$image");
?>
